create table #dblib0016 (b1 bit, b2 bit, i1 int not null, b3 bit, b4 bit)
go
select * from #dblib0016 where 0=1
go
select * from #dblib0016 where 0=1
go
drop table #dblib0016
go
